Manteia - Proclame la bonne parole 
================================================================

Ce module proclame la bonne parole. Puissent-t-ils
retrouver une totale liberté de pensée cosmique vers un nouvel age
reminiscent.

Vous pouvez l'installer avec pip:

    pip install Manteia

Exemple d'usage:

    >>> from Manteia import testManteia
    >>> testManteia()

Ce code est sous licence WTFPL.
